﻿; (function ($) {

	// Imports ================================================================
	var kendo = window.kendo,
        dataviz = kendo.dataviz,
        deepExtend = kendo.deepExtend;

	// Constants ==============================================================
	var BAR_GAP = 1.5,
        BAR_SPACING = 0.4,
		CANDLESTICK_GAP = 1,
		CANDLESTICK_SPACING = 0.3,
        BLACK = "#000",
        SANS = "Arial,Helvetica,sans-serif",
        SANS11 = "11px " + SANS,
        SANS12 = "12px " + SANS,
        SANS16 = "16px " + SANS,
        WHITE = "#fff";

	// Chart themes ============================================================
	var chartBaseTheme = {
		title: {
			font: SANS16
		},
		legend: {
			labels: {
				font: SANS12
			},
			inactiveItems: {
				labels: {
					color: "#A1A7AB"
				},
				markers: {
					color: "#A1A7AB"
				}
			}
		},
		seriesDefaults: {
			visible: true,
			labels: {
				font: SANS11
			},
			area: {
				opacity: 0.4,
				markers: {
					visible: false,
					size: 6
				},
				line: {
					opacity: 1,
					width: 1
				}
			},
			line: {
				width: 1
			},
			bar: {
				gap: BAR_GAP,
				spacing: BAR_SPACING
			},
			column: {
				gap: BAR_GAP,
				spacing: BAR_SPACING
			},
			rangeColumn: {
				gap: BAR_GAP,
				spacing: BAR_SPACING
			},
			rangeBar: {
				gap: BAR_GAP,
				spacing: BAR_SPACING
			},
			candlestick: {
				gap: CANDLESTICK_GAP,
				spacing: CANDLESTICK_SPACING,
				aggregate: {
					open: "max",
					high: "max",
					low: "min",
					close: "max",
					noteText: "first"
				}
			},
			scatterLine: {
				width: 1
			},
			radarLine: {
				width: 4,
				markers: {
					visible: false
				}
			},
			radarArea: {
				opacity: 0.5,
				markers: {
					visible: false,
					size: 6
				},
				line: {
					opacity: 1,
					width: 0
				}
			},
			polarLine: {
				width: 4,
				markers: {
					visible: false
				}
			},
			polarArea: {
				opacity: 0.5,
				markers: {
					visible: false,
					size: 6
				},
				line: {
					opacity: 1,
					width: 0
				}
			},
			funnel: {
				labels: {
					color: "",
					background: ""
				}
			},
			boxPlot: {
				outliersField: "",
				meanField: "",
				whiskers: {
					width: 1,
					color: BLACK
				},
				mean: {
					width: 1,
					color: BLACK
				},
				median: {
					width: 1,
					color: BLACK
				},
				border: {
					width: 1,
					_brightness: 0.8
				},
				gap: 1,
				spacing: 0.3,
				downColor: WHITE,
				highlight: {
					whiskers: {
						width: 2
					},
					mean: {
						width: 2
					},
					median: {
						width: 2
					},
					border: {
						width: 2,
						opacity: 1
					}
				}
			}
		},
		axisDefaults: {
			labels: {
				font: SANS12
			},
			title: {
				font: SANS16,
				margin: 5
			},
			majorGridLines: {
				width: 1
			}
		},
		tooltip: {
			font: SANS12
		},
		navigator: {
			pane: {
				height: 90,
				margin: {
					top: 10
				}
			}
		}
	};

	var chartThemes = {

		Black: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "GREEN"
				},
				legend: {
					labels: {
						color: "RED"
					}
				},
				seriesDefaults: {
					labels: {
						color: "BLUE"
					},
					line: {
						markers: {
							background: "#3d3d3d"
						}
					},
					verticalLine: {
						markers: {
							background: "#3d3d3d"
						}
					},
					scatter: {
						markers: {
							background: "#3d3d3d"
						}
					},
					scatterLine: {
						markers: {
							background: "#3d3d3d"
						}
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#888888"
					}
				},
				chartArea: {
					background: "PURPLE"
				},
				seriesColors: ["YELLOW", "#1edee2", "#9eda29", "#ffce00", "#dd007f", "#01ae98", "#ffc961", "#ff6714", "#fa1852", "#008bcb"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#919191"
					},
					labels: {
						color: WHITE
					},
					majorGridLines: {
						color: "#636363"
					},
					minorGridLines: {
						color: "#464646"
					},
					title: {
						color: WHITE
					}
				},
				tooltip: {
					color: WHITE
				}
			})

		},

		BlackMetroTouch: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: WHITE
				},
				legend: {
					labels: {
						color: WHITE
					}
				},
				seriesDefaults: {
					overlay: {
						gradient: "none"
					},
					labels: {
						color: WHITE
					},
					line: {
						markers: {
							background: "#000000"
						}
					},
					verticalLine: {
						markers: {
							background: "#000000"
						}
					},
					scatter: {
						markers: {
							background: "#000000"
						}
					},
					scatterLine: {
						markers: {
							background: "#000000"
						}
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#888888"
					}
				},
				chartArea: {
					background: "#000000"
				},
				seriesColors: ["#25a0da", "#309b46", "#d8e404", "#e61e26", "#515151", "#2568cc", "#9dd418", "#ffc924", "#ff7200", "#af0007"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#919191"
					},
					labels: {
						color: WHITE
					},
					majorGridLines: {
						color: "#636363"
					},
					minorGridLines: {
						color: "#464646"
					},
					title: {
						color: WHITE
					}
				},
				tooltip: {
					color: WHITE
				}
			})

		},

		Default: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#f6921e", "#d6de23", "#8bc53f", "#26a9e0", "#9e1f63", "#61b045", "#d4ae18", "#f7742c", "#9e0c40", "#136bc5"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					majorGridLines: {
						color: "#aaaaaa"
					},
					minorGridLines: {
						color: "#cccccc"
					},
					line: {
						color: "#828282"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#999999"
					}
				}
			})

		},

		Glow: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "WHITE"
				},
				legend: {
					labels: {
						color: "WHITE"
					}
				},
				seriesDefaults: {
					labels: {
						color: "WHITE"
					},
					verticalLine: {
						markers: {
							background: "#d3e0c2"
						}
					},
					line: {
						markers: {
							background: "#d3e0c2"
						}
					},
					scatter: {
						markers: {
							background: "#d3e0c2"
						}
					},
					scatterLine: {
						markers: {
							background: "#d3e0c2"
						}
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#617078"
					}
				},
				chartArea: {
					background: "#29343b"
				},
				seriesColors: ["#f89d26", "#b8e54b", "#52d5f6", "#ffd800", "#277db4", "#01ae98", "#fffc00", "#f7742c", "#9fcf2d", "#008bcb"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					majorGridLines: {
						color: "#5c6a73"
					},
					minorGridLines: {
						color: "#3a454b"
					},
					line: {
						color: "WHITE"
					},
					labels: {
						color: "WHITE"
					},
					title: {
						color: "WHITE"
					}
				},

				tooltip: {
					color: WHITE
				}
			})

		},

		Metro: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#25a0da", "#309b46", "#d8e404", "#e61e26", "#313131", "#43bcf5", "#9dd418", "#ffc924", "#c4001c", "#0e53bb"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					majorGridLines: {
						color: "#b4b4b4"
					},
					line: {
						color: "#b4b4b4"
					},
					minorGridLines: {
						color: "#d2d2d2"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					overlay: {
						gradient: "none"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				}
			})

		},

		MetroTouch: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#25a0da", "#309b46", "#d8e404", "#e61e26", "#313131", "#43bcf5", "#9dd418", "#ffc924", "#c4001c", "#0e53bb"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					majorGridLines: {
						color: "#b4b4b4"
					},
					line: {
						color: "#b4b4b4"
					},
					minorGridLines: {
						color: "#d2d2d2"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					overlay: {
						gradient: "none"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				}
			})

		},


		Office2007: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#99c62a", "#27adcc", "#2477c9", "#7042b2", "#d83636", "#5f9c40", "#73cae3", "#00738d", "#e96969", "#a4355f"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					majorGridLines: {
						color: "#bdcce2"
					},
					minorGridLines: {
						color: "#d7e0ee"
					},
					line: {
						color: "#688CAF"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				}
			})

		},

		Office2010Black: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: WHITE
				},
				legend: {
					labels: {
						color: WHITE
					}
				},
				seriesDefaults: {
					labels: {
						color: WHITE
					},
					verticalLine: {
						markers: {
							background: "#6f6f6f"
						}
					},
					line: {
						markers: {
							background: "#6f6f6f"
						}
					},
					scatter: {
						markers: {
							background: "#6f6f6f"
						}
					},
					scatterLine: {
						markers: {
							background: "#6f6f6f"
						}
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				},
				chartArea: {
					background: "#6f6f6f"
				},
				seriesColors: ["#99c62a", "#27adcc", "#2477c9", "#7042b2", "#d83636", "#5f9c40", "#73cae3", "#00738d", "#e96969", "#a4355f"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#999999"
					},
					labels: {
						color: WHITE
					},
					majorGridLines: {
						color: "#888888"
					},
					minorGridLines: {
						color: "#7c7c7c"
					},
					title: {
						color: WHITE
					}
				},
				tooltip: {
					color: WHITE
				}
			})

		},

		Office2010Blue: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#384E73"
				},
				legend: {
					labels: {
						color: "#384E73"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#384E73"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				},
				seriesColors: ["#99c62a", "#27adcc", "#2477c9", "#7042b2", "#d83636", "#5f9c40", "#73cae3", "#00738d", "#e96969", "#a4355f"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#8ba0bc"
					},
					labels: {
						color: "#384e73"
					},
					majorGridLines: {
						color: "#d1dbe5"
					},
					minorGridLines: {
						color: "#e3e9ef"
					},
					title: {
						color: "#384e73"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		Office2010Silver: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#3b3b3b"
				},
				legend: {
					labels: {
						color: "#3b3b3b"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#3b3b3b"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				},
				seriesColors: ["#99c62a", "#27adcc", "#2477c9", "#7042b2", "#d83636", "#5f9c40", "#73cae3", "#00738d", "#e96969", "#a4355f"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#a4abb2"
					},
					labels: {
						color: "#3b3b3b"
					},
					majorGridLines: {
						color: "#dbdfe4"
					},
					minorGridLines: {
						color: "#e9ecef"
					},
					title: {
						color: "#3b3b3b"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		Outlook: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#231f20", "#1b75bb", "#7da5e0", "#f9ec31", "#faaf40", "#355cb4", "#d9ce2a", "#58b6ff", "#e89324", "#767676"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#5d8cc9"
					},
					majorGridLines: {
						color: "#aac3e8"
					},
					minorGridLines: {
						color: "#ccdbf1"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				}
			})

		},

		Silk: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#2dabc1", "#8ac24e", "#f1ac4a", "#326eb9", "#a34973", "#48a69e", "#dd7774", "#4a9ddc", "#912357", "#83b66f"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#767676"
					},
					majorGridLines: {
						color: "#c8c8c8"
					},
					minorGridLines: {
						color: "#e8e8e8"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				}
			})

		},

		Simple: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#606060"
				},
				legend: {
					labels: {
						color: "#606060"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					overlay: {
						gradient: "none"
					},
					labels: {
						color: "#606060"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				},
				seriesColors: ["#231f20", "#404041", "#58595b", "#808184", "#929497", "#cbcbcb", "#aeaeae", "#7e7e7e", "#272727", "#000000"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#828282"
					},
					majorGridLines: {
						color: "#d1d1d1"
					},
					minorGridLines: {
						color: "#e3e3e3"
					},
					labels: {
						color: "#606060"
					},
					title: {
						color: "#606060"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		Sunset: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#854324"
				},
				legend: {
					labels: {
						color: "#854324"
					}
				},
				seriesDefaults: {
					labels: {
						color: "#854324"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#b7aca7"
					}
				},
				chartArea: {
					background: ""
				},
				seriesColors: ["#3f1c12", "#ba3b01", "#d95a1a", "#e7931e", "#f9bc12", "#571414", "#cd2929", "#e26d52", "#fc9d5e", "#ffbf6d"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#b7836a"
					},
					labels: {
						color: "#854324"
					},
					majorGridLines: {
						color: "#cebab1"
					},
					minorGridLines: {
						color: "#e2d6d0"
					},
					title: {
						color: "#854324"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		Telerik: {
			chart: deepExtend({}, chartBaseTheme, {
				chartArea: {
					background: ""
				},
				seriesColors: ["#7e7e7e", "#cbcbcb", "#a2ea8b", "#63ac39", "#000000", "#39830f", "#75cc43", "#a2a2a2", "#404040", "#153b00"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#828282"
					},
					majorGridLines: {
						color: "#c6c6c6"
					},
					minorGridLines: {
						color: "#b4b4b4"
					}
				},
				tooltip: {
					color: BLACK
				},
				seriesDefaults: {
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#cccccc"
					}
				}
			})

		},

		Vista: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#333333"
				},
				legend: {
					labels: {
						color: "#333333"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#333333"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#999999"
					}
				},
				seriesColors: ["#83abc0", "#64d6f4", "#3399ff", "#03597a", "#000000", "#0066cc", "#1faeff", "#1773a6", "#777d8b", "#003d5c"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#a7bac5"
					},
					majorGridLines: {
						color: "#d3d3d3"
					},
					labels: {
						color: "#333333"
					},
					minorGridLines: {
						color: "#e5e5e5"
					},
					title: {
						color: "#333333"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		Web20: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#001454"
				},
				legend: {
					labels: {
						color: "#001454"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#001454"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#999999"
					}
				},
				seriesColors: ["#0e4302", "#64ba36", "#a0beea", "#3460b9", "#2c4072", "#b1df97", "#3cae00", "#2864e1", "#6b8dc2", "#001d89"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#708dc3"
					},
					majorGridLines: {
						color: "#cfd9e7"
					},
					labels: {
						color: "#001454"
					},
					minorGridLines: {
						color: "#e2e8f1"
					},
					title: {
						color: "#001454"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		},

		WebBlue: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#0d202b"
				},
				legend: {
					labels: {
						color: "#0d202b"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#0d202b"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#bbbbbb"
					}
				},
				seriesColors: ["#a2b3c7", "#76c8e8", "#358db0", "#426682", "#2d3d4f", "#2a72ab", "#77aadc", "#48beec", "#005475", "#050e31"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#708dc3"
					},
					majorGridLines: {
						color: "#d0d8dd"
					},
					labels: {
						color: "#0d202b"
					},
					minorGridLines: {
						color: "#e2e8f1"
					},
					title: {
						color: "#0d202b"
					}
				},
				tooltip: {
					color: BLACK
				}
			})
		},

		Windows7: {
			chart: deepExtend({}, chartBaseTheme, {
				title: {
					color: "#4c607a"
				},
				legend: {
					labels: {
						color: "#4c607a"
					}
				},
				chartArea: {
					background: ""
				},
				seriesDefaults: {
					labels: {
						color: "#4c607a"
					},
					area: {
						opacity: 0.4
					},
					candlestick: {
						downColor: "#cccccc"
					}
				},
				seriesColors: ["#a5b3c5", "#82afe5", "#358db0", "#03597a", "#152435", "#48beec", "#326fbe", "#698cb5", "#6babc5", "#83c8f4"],
				categoryAxis: {
					majorGridLines: {
						visible: true
					}
				},
				axisDefaults: {
					line: {
						color: "#a5b3c5"
					},
					majorGridLines: {
						color: "#dae2e8"
					},
					labels: {
						color: "#4c607a"
					},
					minorGridLines: {
						color: "#e9eef1"
					},
					title: {
						color: "#4c607a"
					}
				},
				tooltip: {
					color: BLACK
				}
			})

		}

	};

	// Exports ================================================================
	deepExtend(dataviz.ui, {
		themes: chartThemes
	});


})($telerik.$);